@@ -172,14 +172,16 @@ class CGCalendar extends CGExtensions
   
 
   function GetFriendlyName()
-    {
-      return $this->Lang('cal_calendar');
-    }
+  {
+	$tmp = $this->GetPreference('friendlyname');
+	if( !$tmp ) $tmp = $this->Lang('cal_calendar');
+	return $tmp;
+  }
   
   function GetAuthor()
-    {
-      return 'Rob Allen/Calguy1000/Morten Poulsen';
-    }
+  {
+	return 'Rob Allen/Calguy1000/Morten Poulsen';
+  }
   
   function GetAuthorEmail()
     {
@@ -216,7 +218,7 @@ class CGCalendar extends CGExtensions
 
   function GetVersion()
     {
-      return '1.9.7';
+      return '1.10.0.1';
     }
 
   function GetDependencies()
@@ -581,10 +583,16 @@ class CGCalendar extends CGExtensions
 
       $result = array();
       $rs = $db->Execute($sql);
-      if($rs && $rs->RecordCount() > 0)
-	{
-	  $result = $rs->GetArray();			
-	}
+      if($rs && $rs->RecordCount() > 0) {
+		$result = $rs->GetArray();
+		if( is_array($result) && count($result) ) {
+		  foreach( $result as &$one ) {
+			if( $one['field_extra'] != '' ) {
+			  $one['field_extra'] = unserialize($one['field_extra']);
+			}
+		  }
+		}
+	  }
       return $result;		
     }
 
@@ -602,23 +610,25 @@ class CGCalendar extends CGExtensions
       $db->Execute($sql);
     }
 	
-  function AdminAddField($field_newname,$field_type = 0,$field_searchable = 0)
+  function AdminAddField($field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
     {
       $db = $this->GetDb(); /* @var $db ADOConnection */
       $sql = 'INSERT INTO ' . $this->fields_table_name . '
-                (field_name,field_type,field_searchable)
-              VALUES (?,?,?)';
-      $db->Execute($sql,array($field_newname,$field_type,$field_searchable));
+                (field_name,field_type,field_searchable,field_extra)
+              VALUES (?,?,?,?)';
+	  if( $field_extra ) $field_extra = serialize($field_extra);
+      $db->Execute($sql,array($field_newname,$field_type,$field_searchable,$field_extra));
     }
 	
-  function AdminUpdateField($field_oldname,$field_newname,$field_type = 0,$field_searchable = 0)
+  function AdminUpdateField($field_oldname,$field_newname,$field_type = 0,$field_searchable = 0,$field_extra = '')
     {
       $db = $this->GetDb(); /* @var $db ADOConnection */
 
       $sql = 'UPDATE ' . $this->fields_table_name . '
-                 SET field_name = ?, field_type = ?, field_searchable = ?
+                 SET field_name = ?, field_type = ?, field_searchable = ?, field_extra = ?
                WHERE field_name = ?';
-      $db->Execute($sql,array($field_newname, $field_type, $field_searchable, $field_oldname));
+	  if( $field_extra ) $field_extra = serialize($field_extra);
+      $db->Execute($sql,array($field_newname, $field_type, $field_searchable, $field_extra, $field_oldname));
       $sql = 'UPDATE ' . $this->event_field_values_table_name . ' SET field_name = ? WHERE field_name = ?';
       $db->Execute($sql,array($field_newname, $field_oldname));
     }
