@@ -1,6 +1,9 @@
 <?php
 # Simple Language file for the Calendar module.
 # Copyright (c) 2004 by Rob Allen <rob@akrabat.com>
+$lang['prompt_friendlyname'] = 'Friendly Name for this Module in Admin Navigation';
+$lang['info_friendlyname'] = 'Note: You may need to clear the site cache for this preference to have effect.  If no value is supplied a default will be used.';
+$lang['use_wysiwyg'] = 'Use Wysiwyg';
 $lang['error_insufficientparams'] = 'Insufficient Parameters';
 $lang['column_delimiter'] = 'Import file column delimiter';
 $lang['import_completed'] = 'Import Complete';
