@@ -1,4 +1,59 @@
 <?php
+$lang['import_completed'] = 'Import vollst&auml;ndig';
+$lang['num_imported'] = 'Anzahl der eingetragenen Termine: %d';
+$lang['import_lines'] = 'Anzahl der aus der Datei verarbeiteten Zeilen: %d';
+$lang['errors'] = 'Fehler';
+$lang['error_csvfirstlineinvalidfield'] = 'Feld: %s is not recognized, and is not a custom field';
+$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
+<ul>
+  <li>General Information:
+   <ul>
+     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
+     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
+     <li>Empty lines are ignore.d</li>
+     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
+     <li>Rows are delimited by newline chars (as above).</li>
+   </ul>
+  </li>
+  <li>The Field Map:
+   <ul>
+    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
+    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
+    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
+   </ul>
+  </li>
+  <li>The Data Rows:
+   <ul>
+    <li>The start time, title, and description fields must not be empty.</li>
+<li>Start and End Times:</li>
+  <ul>
+   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
+   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
+   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
+   <li>If the end time column is empty, then no end time value will be created in the database.</li>
+  </ul>
+</li>
+<li>Categories
+  <ul>
+   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
+   <li>Category names are case sensitive.</li>
+   <li>Categories are not created if they do not exist.</li>
+  </ul>
+</li>
+<li>Custom Fields:
+  <ul>
+    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
+    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
+    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
+  </ul>
+  </li>
+  </ul>
+</li>
+<li>A sample csv file exists in the modules source code directory.</li>
+</ul>';
+$lang['prompt_csv_file'] = 'Die zu importierende Datei ausw&auml;hlen';
+$lang['delete'] = 'L&ouml;schen';
+$lang['cd_company'] = 'Firmenverzeichnis';
 $lang['dflt_urlprefix'] = 'Voreingestelltes URL-Pr&auml;fix f&uuml;r Pretty URLs';
 $lang['dflt_alldayevent'] = 'Neue Termine sollen voreingestellt ganzt&auml;gig sein';
 $lang['dflt_starttime'] = 'Voreingestellte Startzeit f&uuml;r neue Termine';
@@ -6,16 +61,16 @@ $lang['info_dflt_starttime'] = '<em>(wird nur dann angewendet, wenn neue Termine
 $lang['search_type'] = 'Such-Typ';
 $lang['search_any'] = 'Gibt Ergebnisse zur&uuml;ck, wenn irgend ein Wort enthalten ist';
 $lang['search_all'] = 'Gibt Ergebnisse zur&uuml;ck, wenn alle Worte enthalten sind';
-$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Hinweis:</span> Felder zum Hochladen von Dateien k&ouml;nnen nicht durchsucht werden.';
+$lang['info_customfields'] = '<strong style=&quot;color: red;&quot;>Hinweis:</strong> Felder zum Hochladen von Dateien k&ouml;nnen nicht durchsucht werden.';
 $lang['searchable'] = 'Durchsuchbar';
-$lang['help_param_editeventtemplate'] = 'Kann nur zusammen mit der Aktion myevents verwendet werden. Mit diesem Parameter kann ein von den Voreinstellungen abweichendes Template festgelegt werden, wenn ein Benutzer einen Termin erstellt oder bearbeitet';
+$lang['help_param_editeventtemplate'] = 'Kann nur zusammen mit der Aktion &bdquo;myevents&ldquo; verwendet werden. Mit diesem Parameter kann ein von den Voreinstellungen abweichendes Template festgelegt werden, wenn ein Benutzer einen Termin erstellt oder bearbeitet';
 $lang['help_param_editpage'] = 'Kann nur zusammen mit der Aktion myevents verwendet werden. Mit diesem Parameter kann eine von den Voreinstellungen abweichende Seite f&uuml;r das Bearbeitungsformular festgelegt werden.';
 $lang['help_param_myeventstemplate'] = 'Kann nur zusammen mit der Aktion myevents verwendet werden. Mit diesem Parameter kann ein von den Voreinstellungen abweichendes Template festgelegt werden.';
 $lang['cal_edit_event'] = 'Kalender-Eintrag bearbeiten';
 $lang['error_dberror'] = 'Datenbankfehler';
 $lang['submit'] = 'Absenden';
-$lang['info_sysdflt_editevent_template'] = 'Voreingestelltes Template f&uuml;r &quot;Termin bearbeiten&quot;';
-$lang['info_sysdflt_myevents_template'] = 'Voreingestelltes Template f&uuml;r &quot;Meine Termine&quot; Template';
+$lang['info_sysdflt_editevent_template'] = 'Voreingestelltes Template f&uuml;r &bdquo;Termin bearbeiten&ldquo;';
+$lang['info_sysdflt_myevents_template'] = 'Voreingestelltes Template f&uuml;r &bdquo;Meine Termine&ldquo;';
 $lang['prompt_feedit_group'] = 'Mitglieder dieser FEU-Gruppe d&uuml;rfen Termine hinzuf&uuml;gen';
 $lang['prompt_feedit_page'] = 'Voreingestellte Seite f&uuml;r das Bearbeitungsformular auf der Webseite/Frontend';
 $lang['none'] = 'Kein(e)/ohne Vorgabe';
@@ -43,10 +98,10 @@ $lang['lbl_templates'] = 'Templates ';
 $lang['textarea'] = 'Textbereich';
 $lang['error_calendar_incompatible'] = 'Es wurde festgestellt, dass das Modul &bdquo;Calendar&ldquo; ebenfalls installiert ist. Dieses Modul ist NICHT kompatibel mit dem Modul &bdquo;Calendar&ldquo; und kann auch NICHT gleichzeitig installiert sein. Bitte deinstallieren Sie das &bdquo;Calendar&ldquo;-Modul.';
 $lang['error_event_not_found'] = 'Entweder ist die event_id nicht in der Datenbank vorhanden, oder es gibt mehrere Eintr&auml;ge mit dieser ID! (%d)';
-$lang['first_page'] = '<<';
-$lang['prev_page'] = '<';
-$lang['next_page'] = '>';
-$lang['last_page'] = '>>';
+$lang['first_page'] = '&amp;lt;&amp;lt;';
+$lang['prev_page'] = '&amp;lt;';
+$lang['next_page'] = '&amp;gt;';
+$lang['last_page'] = '&amp;gt;&amp;gt;';
 $lang['page_of'] = 'Seite %d von %d';
 $lang['search_results'] = 'Kalender-Suchergebnisse';
 $lang['search_words'] = 'Suchbegriffe';
@@ -175,56 +230,123 @@ $lang['eventdesc-CategoryEdited'] = 'Ausf&uuml;hren, nachdem eine Kategorie bear
 $lang['eventdesc-CategoryDeleted'] = 'Ausf&uuml;hren, nachdem eine Kategorie gel&ouml;scht wurde';
 $lang['eventhelp-EventAdded'] = '<p>Ausf&uuml;hren, wenn ein Termin hinzugef&uuml;gt wurde.</p>
 <h4>Parameter</h4>
-<ul>
-<li>&bdquo;event_title&ldquo; &ndash; Name des Termins</li>
-<li>&bdquo;event_summary&ldquo; &ndash; Zusammenfassung des Termins</li>
-<li>&bdquo;event_details&ldquo; &ndash; Detaillierte Beschreibung</li>
-<li>&bdquo;event_date_start&ldquo; &ndash; Startdatum/-zeit des Termins</li>
-<li>&bdquo;event_date_end&ldquo; &ndash; Enddatum/-zeit des Termins</li>
-<li>&bdquo;event_created_by&ldquo; &ndash; Benutzer-ID des Autors</li>
-<li>&bdquo;event_id&ldquo; &ndash; ID des Termins</li>
-</ul>
+<table>
+<tr>
+<th>event_title</th>
+<td>Name des Termins</td>
+</tr>
+<tr>
+<th>event_summary</th>
+<td>Zusammenfassung des Termins</td>
+</tr>
+<tr>
+<th>event_details</th>
+<td>Detaillierte Beschreibung</td>
+</tr>
+<tr>
+<th>event_date_start</th>
+<td>Startdatum/-zeit des Termins</td>
+</tr>
+<tr>
+<th>event_date_end</th>
+<td>Enddatum/-zeit des Termins</td>
+</tr>
+<tr>
+<th>event_created_by</th>
+<td>Benutzer-ID des Autors</td>
+</tr>
+<tr>
+<th>event_id</th>
+<td>ID des Termins</td>
+</tr>
+</table>
 ';
 $lang['eventhelp-EventEdited'] = '<p>Ausf&uuml;hren, wenn ein Termin bearbeitet wurde.</p>
 <h4>Parameter</h4>
-<ul>
-<li>&bdquo;event_title&ldquo; &ndash; Name des Termins</li>
-<li>&bdquo;event_summary&ldquo; &ndash; Zusammenfassung des Termins</li>
-<li>&bdquo;event_details&ldquo; &ndash; Detaillierte Beschreibung</li>
-<li>&bdquo;event_date_start&ldquo; &ndash; Startdatum/-zeit des Termins</li>
-<li>&bdquo;event_date_end&ldquo; &ndash; Enddatum/-zeit des Termins</li>
-<li>&bdquo;event_created_by&ldquo; &ndash; Benutzer-ID des Autors</li>
-<li>&bdquo;event_id&ldquo; &ndash; ID des Termins</li>
-</ul>
+<table>
+<tr>
+<th>event_title</th>
+<td>Name des Termins</td>
+</tr>
+<tr>
+<th>event_summary</th>
+<td>Zusammenfassung des Termins</td>
+</tr>
+<tr>
+<th>event_details</th>
+<td>Detaillierte Beschreibung</td>
+</tr>
+<tr>
+<th>event_date_start</th>
+<td>Startdatum/-zeit des Termins</td>
+</tr>
+<tr>
+<th>event_date_end</th>
+<td>Enddatum/-zeit des Termins</td>
+</tr>
+<tr>
+<th>event_created_by</th>
+<td>Benutzer-ID des Autors</td>
+</tr>
+<tr>
+<th>event_id</th>
+<td>ID des Termins</td>
+</tr>
+</table>
 ';
 $lang['eventhelp-EventDeleted'] = '<p>Ausf&uuml;hren, wenn ein Termin gel&ouml;scht wurde.</p>
 <h4>Parameter</h4>
-<ul>
-<li>&bdquo;event_id&ldquo; &ndash; ID des Termins</li>
-</ul>
-';
+<table>
+<tr>
+<th>event_id</th>
+<td>ID des Termins</td>
+</tr>
+</table>';
 $lang['eventhelp-CategoryAdded'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kategorie hinzugef&uuml;gt wurde.</p>
 <h4>Parameter</h4>
-<ul>
-<li>&bdquo;category_id&ldquo; &ndash; ID der Kategorie</li>
-</ul>
+<table>
+<tr>
+<th>category_id</th>
+<td>ID der Kategorie</td>
+</tr>
+</table>
 ';
 $lang['eventhelp-CategoryEdited'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kategorie bearbeitet wurde.</p>
 <h4>Parameter</h4>
-<ul>
-<li>&bdquo;category_id&ldquo; &ndash; ID der Kategorie</li>
-<li>&bdquo;category_name&ldquo; &ndash; Name der Kategorie</li>
-<li>&bdquo;category_order&ldquo; &ndash; Sortierung der Kategorie</li>
-</ul>
-';
+<table>
+<tr>
+<th>category_id</th>
+<td>ID der Kategorie</td>
+</tr>
+<tr>
+<th>category_name</th>
+<td>Name der Kategorie</td>
+</tr>
+<tr>
+<th>category_order</th>
+<td>Sortierung der Kategorie</td>
+</tr>
+</table>';
 $lang['eventhelp-CategoryDeleted'] = '<p>Ausf&uuml;hren, wenn eine Kalender-Kategorie gel&ouml;scht wurde.</p>
 <h4>Parameter</h4>
-<ul>
-<li>&bdquo;category_id&ldquo; &ndash; ID der Kategorie</li>
-<li>&bdquo;category_name&ldquo; &ndash; Name der Kategorie</li>
-<li>&bdquo;category_order&ldquo; &ndash; Sortierung der Kategorie</li>
-</ul>
+<table>
+<tr>
+<th>category_id</th>
+<td>ID der Kategorie</td>
+</tr>
+<tr>
+<th>category_name</th>
+<td>Name der Kategorie</td>
+</tr>
+<tr>
+<th>category_order</th>
+<td>Sortierung der Kategorie</td>
+</tr>
+</table>
 ';
+$lang['error_csv_insert'] = 'Fehler beim Importieren eines Termins in der CSV-Datei in Zeile %d';
+$lang['error_csvfirstlinefldnotfound'] = 'Das Pflichtfeld %s konnte in der Kopfzeile der CSV nicht gefunden werden';
+$lang['error_csvinvalidfirstline'] = 'In der CSV-Datei konnte keine g&uuml;ltige erste Zeile gefunden werden';
 $lang['msg_eventadded'] = 'Termin hinzugef&uuml;gt';
 $lang['error_noeventname'] = 'Sie m&uuml;ssen einen Namen f&uuml;r den Termin eingeben';
 $lang['error_noupload'] = 'FEHLER: Es wurde keine hochgeladene Datei gefunden';
@@ -236,7 +358,7 @@ $lang['error_csvfilenotfound'] = 'FEHLER: Konnte die CSV-Datei nicht finden';
 $lang['error_cantopenfile'] = 'FEHLER: Konnte die Datei nicht &ouml;ffnen';
 $lang['error_categoryexists'] = 'FEHLER: Eine Kategorie mit dem Namen %s existiert bereits';
 $lang['cal_id'] = 'ID';
-$lang['cal_calendar'] = 'Calguys Kalender';
+$lang['cal_calendar'] = 'Kalender (&bdquo;CGCalendar&ldquo;)';
 $lang['cal_default_templates'] = 'Standard-Templates';
 $lang['cal_description'] = 'Ein flexibles Modul, um Informationen &uuml;ber Termine in verschiedenen Formaten anzeigen.';
 $lang['cal_addevent'] = 'Termin hinzuf&uuml;gen';
@@ -299,8 +421,8 @@ $lang['cal_show_only_events_in'] = 'Nur Termine anzeigen aus';
 $lang['cal_filter_by'] = 'Titel filtern mit <em>(regex)</em> ';
 $lang['cal_go'] = 'Filtern';
 $lang['cal_title'] = 'Titel';
-$lang['cal_fromdate'] = '&quot;Von&quot;-Datum';
-$lang['cal_todate'] = '&quot;Bis&quot;-Datum';
+$lang['cal_fromdate'] = 'Anfangsdatum';
+$lang['cal_todate'] = 'Enddatum';
 $lang['cal_update_categories'] = 'Kategorien aktualisieren';
 $lang['cal_language'] = 'Sprache';
 $lang['cal_updatesettings'] = 'Einstellungen aktualisieren';
@@ -333,8 +455,8 @@ $lang['templateimported'] = 'Das Template wurde erfolgreich in die Datenbank imp
 $lang['view_default_stylesheet'] = 'Standard-Stylesheet anzeigen';
 $lang['filename'] = 'Dateiname';
 $lang['importtemplate'] = 'Template importieren';
-$lang['template_deleted'] = 'Das Template wurde erfolgreich aus der Datenbank gel&ouml;scht.';
-$lang['updatetemplatesuccess'] = 'Das Template wurde erfolgreich aktualisiert.';
+$lang['template_deleted'] = 'Das Template wurde aus der Datenbank gel&ouml;scht.';
+$lang['updatetemplatesuccess'] = 'Das Template wurde aktualisiert.';
 $lang['updatetemplatefailure'] = 'Beim Aktualisieren des Templates ist ein Fehler aufgetreten.';
 $lang['settingssaved'] = 'Die Einstellungen wurden erfolgreich gespeichert.';
 $lang['categorydeleted'] = 'Kategorie gel&ouml;scht';
@@ -363,7 +485,7 @@ $lang['large_width'] = 'Breite des gro&szlig;en Bildes';
 $lang['large_height'] = 'H&ouml;he des gro&szlig;en Bildes';
 $lang['cal_recur_period'] = 'Wiederholen';
 $lang['cal_recur_until'] = 'Wiederholen bis';
-$lang['help_template'] = '<p><b>Name des Autors ausgeben:</b></p>
+$lang['help_template'] = '<p><strong>Name des Autors ausgeben:</strong></p>
 <code>Autor: {$event.authorname}</code>
 ';
 $lang['cal_help'] = '<h3>Hinweis:</h3>
@@ -375,9 +497,9 @@ $lang['cal_help'] = '<h3>Hinweis:</h3>
 <h3>Wie wird es eingesetzt ?</h3>
  <ol>
   <li>F&uuml;gen Sie den {cms_module}-Tag in eine Seite ein. Achten Sie darauf, dass der Code nicht von anderen HTML-Tags (wie etwa <code>pre</code>,<code>code</code> oder &auml;hnlichem) eingeschlossen wird. Kontrollieren Sie den Quellcode. Der einzuf&uuml;gende Code sollte so aussehen:<br />
-   <tt>{cms_module module=&quot;cgcalendar&quot;}</tt><br />
+   <code>{cms_module module=&quot;CGCalendar&quot;}</code> oder einfach <code>{CGCalendar}</code><br />
    <li>Gestalten Sie den Kalender via CSS nach Ihren Vorstellungen (ein Beispiel-Stylesheet wurde Ihrer CSS-Liste mit der Installation hinzugef&uuml;gt).</li>
-   <li>Verbinden Sie dieses Stylesheet mit der Vorlage, welche Sie f&uuml;r die Kalender-Seite nutzen.</li>
+   <li>Verbinden Sie dieses Stylesheet mit dem Template, welches Sie f&uuml;r die Kalender-Seite nutzen.</li>
 </ol>
 <h4>So verbinden Sie das mitgelieferte Stylesheet mit Ihrem Template:</h4>
 <ol>
@@ -464,7 +586,7 @@ $lang['cal_help'] = '<h3>Hinweis:</h3>
 
    <tr>
 	<th>detailpage=&quot;pagealias&quot;</th>
-	<td>Hiermit k&ouml;nnen Sie eine Seite festlegen, auf der die Details zu den Terminen/Ereignissen angezeigt werden sollen. Dies kann ein Seiten-Alias oder auch eine ID sein. Damit wird es m&ouml;glich, die Details mit einer anderen Vorlage als die Zusammenfassung anzeigen zu lassen. Standard ist die aktuelle Seite. <em>(optional)</em></td>
+	<td>Hiermit k&ouml;nnen Sie eine Seite festlegen, auf der die Details zu den Terminen/Ereignissen angezeigt werden sollen. Dies kann ein Seiten-Alias oder auch eine ID sein. Damit wird es m&ouml;glich, die Details mit einem anderen Template als die Zusammenfassung anzeigen zu lassen. Standard ist die aktuelle Seite. <em>(optional)</em></td>
     </tr>
 
    <tr>
@@ -494,37 +616,37 @@ $lang['cal_help'] = '<h3>Hinweis:</h3>
 
   <tr>
      <th>calendartemplate</th>
-     <td>Bei Verwendung des Kalender-Modus kann &uuml;ber diesen Parameter eine Vorlage aus der Liste festgelegt werden, welche f&uuml;r die Anzeige des Kalenders verwendet werden soll (abweichend von dem festgelegten Standard-Vorlage).</td>
+     <td>Bei Verwendung des Kalender-Modus kann &uuml;ber diesen Parameter ein Template aus der Liste festgelegt werden, welche f&uuml;r die Anzeige des Kalenders verwendet werden soll (abweichend von dem festgelegten Standard-Template).</td>
   </tr>
 
   <tr>
      <th>eventtemplate</th>
-     <td>Mit diesem Parameter kann eine Vorlage aus der Liste festgelegt werden, welches f&uuml;r die Anzeige des Ereignisses verwendet werden soll (abweichend von dem festgelegten Standard-Vorlage).</td>
+     <td>Mit diesem Parameter kann ein Template aus der Liste festgelegt werden, welches f&uuml;r die Anzeige des Ereignisses verwendet werden soll (abweichend von dem festgelegten Standard-Template).</td>
   </tr>
 
    <tr>
 	<th>listtemplate</th>
-	<td>Bei Verwendung des &bdquo;list&ldquo;-Modus kann &uuml;ber diesen Parameter festgelegt werden, welches Vorlage f&uuml;r die Listen-Anzeige verwendet werden soll (abweichend von dem festgelegten Standard-Vorlage).</td>
+	<td>Bei Verwendung des &bdquo;list&ldquo;-Modus kann &uuml;ber diesen Parameter festgelegt werden, welches Template f&uuml;r die Listen-Anzeige verwendet werden soll (abweichend von dem festgelegten Standard-Template).</td>
    </tr>
 
    <tr>
 	<th>upcominglisttemplate</th>
-	<td>Bei Verwendung des &bdquo;upcominglist&ldquo;-Modus kann &uuml;ber diesen Parameter festgelegt werden, welches Vorlage f&uuml;r die Anzeige zuk&uuml;nftiger Termine/Ereignisse verwendet wird (abweichend von dem festgelegten Standard-Vorlage).</td>
+	<td>Bei Verwendung des &bdquo;upcominglist&ldquo;-Modus kann &uuml;ber diesen Parameter festgelegt werden, welches Template f&uuml;r die Anzeige zuk&uuml;nftiger Termine/Ereignisse verwendet wird (abweichend von dem festgelegten Standard-Template).</td>
    </tr>
 
   <tr>
      <th>moretext</th>
-     <td>Wird in den verschiedenen Zusammenfassungs-Vorlagen verwendet. &Uuml;ber diesen Parameter kann ein Text f&uuml;r den Link festgelegt werden, der auf die Seite mit der Detail-Anzeige verweist.</td>
+     <td>Wird in den verschiedenen Zusammenfassungs-Templates verwendet. &Uuml;ber diesen Parameter kann ein Text f&uuml;r den Link festgelegt werden, der auf die Seite mit der Detail-Anzeige verweist.</td>
   </tr>
 </table>
 
 <h3>Benutzerdefinierte Felder</h3>
-<p>Es ist au&szlig;erdem m&ouml;glich, benutzerdefinierte Felder zu erstellen, die in der Modul-Administration &uuml;ber die Registerkarte &bdquo;Felder&ldquo; jedem Ereignis zugeordnet werden k&ouml;nnen. Entweder ein oder mehrere Felder definieren die Werte des Feldes f&uuml;r jedes Ereignis. Diese Felder k&ouml;nnen dann &uuml;ber den Registerkarte &bdquo;Ereignisse&ldquo; gef&uuml;llt werden. Die Werte dieser Felder k&ouml;nnen &uuml;ber den Syntax event.field.fieldname in den Vorlagen ausgegeben werden. Ein Tipp: geben Sie {debug} in ihre Vorlage ein, um alle Daten zu sehen, die an die Vorlage &uuml;bergeben werden.</p>
+<p>Es ist au&szlig;erdem m&ouml;glich, benutzerdefinierte Felder zu erstellen, die in der Modul-Administration &uuml;ber die Registerkarte &bdquo;Felder&ldquo; jedem Ereignis zugeordnet werden k&ouml;nnen. Entweder ein oder mehrere Felder definieren die Werte des Feldes f&uuml;r jedes Ereignis. Diese Felder k&ouml;nnen dann &uuml;ber den Registerkarte &bdquo;Ereignisse&ldquo; gef&uuml;llt werden. Die Werte dieser Felder k&ouml;nnen &uuml;ber den Syntax event.field.fieldname in den Templates ausgegeben werden. Ein Tipp: geben Sie {debug} in Ihr Template ein, um alle Daten zu sehen, die an das Template &uuml;bergeben werden.</p>
 
 <h3>Beispiele</h3>
 <h4>Ein Beispiel, wie Sie Kommentare f&uuml;r Termine/Ereignisse verwenden k&ouml;nnen:</h4>
-<p>Installieren Sie das Comments-Modul und rufen es wie folgt im jeweiligen Ereignis-Vorlage auf:</p>
-<pre>{cms_module module=&#039;comments&#039; modulename=&#039;cgcalendar&#039; pageid=$event.event_id}</pre>
+<p>Installieren Sie das Comments-Modul und rufen es wie folgt im jeweiligen Ereignis-Template auf:</p>
+<pre><code>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</code></pre>
 
 <h3>Support</h3>
 <p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
@@ -556,8 +678,8 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['utma'] = '156861353.1472747146.1287205544.1287205544.1287208226.2';
+$lang['utma'] = '156861353.566816069.1326487945.1326487945.1326569148.2';
+$lang['utmz'] = '156861353.1326487945.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1287205544.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
