@@ -1,10 +1,11 @@
 <?php
+$lang['error_insufficientparams'] = 'Param&egrave;tres insuffisant';
 $lang['column_delimiter'] = 'Import file column delimiter';
-$lang['import_completed'] = 'Import Complete';
-$lang['num_imported'] = 'Number of events created: %d';
-$lang['import_lines'] = 'Number of lines processed from file: %d';
+$lang['import_completed'] = 'Importation termin&eacute;';
+$lang['num_imported'] = 'Nombre d&#039;&eacute;v&egrave;nements cr&eacute;&eacute;s: %d';
+$lang['import_lines'] = 'Nombre de lignes trait&eacute;es du fichier: %d';
 $lang['errors'] = 'Erreurs';
-$lang['error_csvfirstlineinvalidfield'] = 'Field: %s is not recognized, and is not a custom field';
+$lang['error_csvfirstlineinvalidfield'] = 'Champs: %s non reconnu, et n&#039;est pas un champs personnalis&eacute;.';
 $lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
 <ul>
   <li>General Information:
@@ -52,7 +53,7 @@ $lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
 </li>
 <li>A sample csv file exists in the modules source code directory.</li>
 </ul>';
-$lang['prompt_csv_file'] = 'Select Import File';
+$lang['prompt_csv_file'] = 'S&eacute;lectionner le fichier d&#039;importation';
 $lang['delete'] = 'Effacer';
 $lang['cd_company'] = 'Company Directory Company';
 $lang['dflt_urlprefix'] = 'Pr&eacute;fixe d&#039;URL par d&eacute;faut pour &quot;pretty URLS&quot;';
@@ -281,9 +282,9 @@ $lang['eventhelp-CategoryDeleted'] = '<p>Envoy&eacute; quand une cat&eacute;gori
 <li>\&quot;category_order\&quot; - L&#039;ordre de tri de la cat&eacute;gorie</li>
 </ul>
 ';
-$lang['error_csv_insert'] = 'Error importing event from csv at line %d';
-$lang['error_csvfirstlinefldnotfound'] = 'A required field: %s, could not be found in the csv file header line';
-$lang['error_csvinvalidfirstline'] = 'Could not find a valid first line of the CSV file';
+$lang['error_csv_insert'] = 'Erreur durant l&#039;importation des &eacute;v&egrave;nements depuis le css &agrave; la ligne %d';
+$lang['error_csvfirstlinefldnotfound'] = 'Un champs obligatoire: %s, n&#039;a pu &ecirc;tre trouv&eacute; dans la ligne d&#039;ent&ecirc;te du fichier csv';
+$lang['error_csvinvalidfirstline'] = 'Ne peut trouver une ligne d&#039;ent&ecirc;te valide dans le fichier CSV';
 $lang['msg_eventadded'] = '&Eacute;v&eacute;nement ajout&eacute;';
 $lang['error_noeventname'] = 'Un nom pour l&#039;&eacute;v&eacute;nement doit &ecirc;tre d&eacute;finit';
 $lang['error_noupload'] = 'ERREUR&nbsp;: Aucun fichier upload&eacute; trouv&eacute;';
@@ -610,6 +611,8 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
 ';
-$lang['qca'] = 'P0-483686814-1251229608352';
-$lang['utma'] = '57867837.1772960952774974200.1251229608.1315083144.1315177962.175';
+$lang['utma'] = '156861353.748041509.1335632272.1335632272.1335774814.2';
+$lang['utmz'] = '156861353.1335632272.1.1.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1335774814';
 ?>
\ No newline at end of file
