@@ -36,7 +36,7 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-$db =& $this->GetDb();				/* @var $db ADOConnection */
+$db = $this->GetDb();				/* @var $db ADOConnection */
 $dict = NewDataDictionary($db); 	/* @var $dict ADODB_DataDict */
 
 $table_options = array('mysql' => 'TYPE=MyISAM');
@@ -254,7 +254,7 @@ $this->CreatePermission('Modify Calendar', 'Modify Calendar');
 $this->CreatePermission('Manage Calendar Attributes','Manage Calendar Attributes');
 
 //Insert example stylesheet
-$config =& $gCms->GetConfig();
+$config = $gCms->GetConfig();
 $new_css_id = $db->GenID(cms_db_prefix() . "css_seq");
 $css_name = $this->Lang('module_example_stylesheet').' v'.$this->GetVersion();
 $css_text = file_get_contents($config['root_path'] . DIRECTORY_SEPARATOR . 'modules' . DIRECTORY_SEPARATOR . $this->GetName() . DIRECTORY_SEPARATOR . 'css' . DIRECTORY_SEPARATOR . 'stylesheet.css');
@@ -264,4 +264,4 @@ $query = "INSERT INTO " . cms_db_prefix() . "css (css_id, css_name, css_text, me
 $result = $db->Execute($query, array($new_css_id, $css_name, $css_text, $media_type, $db->DBTimeStamp(time()), $db->DBTimeStamp(time())));
 
 
-?>
\ No newline at end of file
+?>
