@@ -35,7 +35,7 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
-$db =& $this->GetDb();				/* @var $db ADOConnection */
+$db = $this->GetDb();				/* @var $db ADOConnection */
 $dict = NewDataDictionary($db); 	/* @var $dict ADODB_DataDict */
 
 switch( $oldversion )
